@@ -46,7 +46,14 @@ class RosTrail(
         :param enable_resource_property_constraint: -
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(RosTrail.__init__)
+            def stub(
+                scope: ros_cdk_core.Construct,
+                id: builtins.str,
+                props: typing.Union["RosTrailProps", typing.Dict[str, typing.Any]],
+                enable_resource_property_constraint: builtins.bool,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
             check_type(argname="argument id", value=id, expected_type=type_hints["id"])
             check_type(argname="argument props", value=props, expected_type=type_hints["props"])
@@ -62,7 +69,9 @@ class RosTrail(
         :param props: -
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(RosTrail._render_properties)
+            def stub(props: typing.Mapping[builtins.str, typing.Any]) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument props", value=props, expected_type=type_hints["props"])
         return typing.cast(typing.Mapping[builtins.str, typing.Any], jsii.invoke(self, "renderProperties", [props]))
 
@@ -93,7 +102,9 @@ class RosTrail(
     @enable_resource_property_constraint.setter
     def enable_resource_property_constraint(self, value: builtins.bool) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(RosTrail, "enable_resource_property_constraint").fset)
+            def stub(value: builtins.bool) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "enableResourcePropertyConstraint", value)
 
@@ -108,7 +119,11 @@ class RosTrail(
     @name.setter
     def name(self, value: typing.Union[builtins.str, ros_cdk_core.IResolvable]) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(RosTrail, "name").fset)
+            def stub(
+                value: typing.Union[builtins.str, ros_cdk_core.IResolvable],
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "name", value)
 
@@ -126,7 +141,11 @@ class RosTrail(
         value: typing.Union[builtins.str, ros_cdk_core.IResolvable],
     ) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(RosTrail, "oss_bucket_name").fset)
+            def stub(
+                value: typing.Union[builtins.str, ros_cdk_core.IResolvable],
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "ossBucketName", value)
 
@@ -144,7 +163,11 @@ class RosTrail(
         value: typing.Union[builtins.str, ros_cdk_core.IResolvable],
     ) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(RosTrail, "role_name").fset)
+            def stub(
+                value: typing.Union[builtins.str, ros_cdk_core.IResolvable],
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "roleName", value)
 
@@ -164,7 +187,11 @@ class RosTrail(
         value: typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]],
     ) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(RosTrail, "event_rw").fset)
+            def stub(
+                value: typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]],
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "eventRw", value)
 
@@ -184,7 +211,11 @@ class RosTrail(
         value: typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]],
     ) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(RosTrail, "oss_key_prefix").fset)
+            def stub(
+                value: typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]],
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "ossKeyPrefix", value)
 
@@ -204,7 +235,11 @@ class RosTrail(
         value: typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]],
     ) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(RosTrail, "sls_project_arn").fset)
+            def stub(
+                value: typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]],
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "slsProjectArn", value)
 
@@ -224,7 +259,11 @@ class RosTrail(
         value: typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]],
     ) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(RosTrail, "sls_write_role_arn").fset)
+            def stub(
+                value: typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]],
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "slsWriteRoleArn", value)
 
@@ -251,7 +290,14 @@ class RosTrailLogging(
         :param enable_resource_property_constraint: -
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(RosTrailLogging.__init__)
+            def stub(
+                scope: ros_cdk_core.Construct,
+                id: builtins.str,
+                props: typing.Union["RosTrailLoggingProps", typing.Dict[str, typing.Any]],
+                enable_resource_property_constraint: builtins.bool,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
             check_type(argname="argument id", value=id, expected_type=type_hints["id"])
             check_type(argname="argument props", value=props, expected_type=type_hints["props"])
@@ -267,7 +313,9 @@ class RosTrailLogging(
         :param props: -
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(RosTrailLogging._render_properties)
+            def stub(props: typing.Mapping[builtins.str, typing.Any]) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument props", value=props, expected_type=type_hints["props"])
         return typing.cast(typing.Mapping[builtins.str, typing.Any], jsii.invoke(self, "renderProperties", [props]))
 
@@ -336,7 +384,11 @@ class RosTrailLogging(
         value: typing.Union[builtins.bool, ros_cdk_core.IResolvable],
     ) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(RosTrailLogging, "enable").fset)
+            def stub(
+                value: typing.Union[builtins.bool, ros_cdk_core.IResolvable],
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "enable", value)
 
@@ -348,7 +400,9 @@ class RosTrailLogging(
     @enable_resource_property_constraint.setter
     def enable_resource_property_constraint(self, value: builtins.bool) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(RosTrailLogging, "enable_resource_property_constraint").fset)
+            def stub(value: builtins.bool) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "enableResourcePropertyConstraint", value)
 
@@ -363,7 +417,11 @@ class RosTrailLogging(
     @name.setter
     def name(self, value: typing.Union[builtins.str, ros_cdk_core.IResolvable]) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(RosTrailLogging, "name").fset)
+            def stub(
+                value: typing.Union[builtins.str, ros_cdk_core.IResolvable],
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "name", value)
 
@@ -386,7 +444,13 @@ class RosTrailLoggingProps:
         :param name: 
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(RosTrailLoggingProps.__init__)
+            def stub(
+                *,
+                enable: typing.Union[builtins.bool, ros_cdk_core.IResolvable],
+                name: typing.Union[builtins.str, ros_cdk_core.IResolvable],
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument enable", value=enable, expected_type=type_hints["enable"])
             check_type(argname="argument name", value=name, expected_type=type_hints["name"])
         self._values: typing.Dict[str, typing.Any] = {
@@ -460,7 +524,18 @@ class RosTrailProps:
         :param sls_write_role_arn: 
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(RosTrailProps.__init__)
+            def stub(
+                *,
+                name: typing.Union[builtins.str, ros_cdk_core.IResolvable],
+                oss_bucket_name: typing.Union[builtins.str, ros_cdk_core.IResolvable],
+                role_name: typing.Union[builtins.str, ros_cdk_core.IResolvable],
+                event_rw: typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]] = None,
+                oss_key_prefix: typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]] = None,
+                sls_project_arn: typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]] = None,
+                sls_write_role_arn: typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]] = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument name", value=name, expected_type=type_hints["name"])
             check_type(argname="argument oss_bucket_name", value=oss_bucket_name, expected_type=type_hints["oss_bucket_name"])
             check_type(argname="argument role_name", value=role_name, expected_type=type_hints["role_name"])
@@ -587,7 +662,14 @@ class Trail(
         :param enable_resource_property_constraint: -
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(Trail.__init__)
+            def stub(
+                scope: ros_cdk_core.Construct,
+                id: builtins.str,
+                props: typing.Union["TrailProps", typing.Dict[str, typing.Any]],
+                enable_resource_property_constraint: typing.Optional[builtins.bool] = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
             check_type(argname="argument id", value=id, expected_type=type_hints["id"])
             check_type(argname="argument props", value=props, expected_type=type_hints["props"])
@@ -627,7 +709,14 @@ class TrailLogging(
         :param enable_resource_property_constraint: -
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(TrailLogging.__init__)
+            def stub(
+                scope: ros_cdk_core.Construct,
+                id: builtins.str,
+                props: typing.Union["TrailLoggingProps", typing.Dict[str, typing.Any]],
+                enable_resource_property_constraint: typing.Optional[builtins.bool] = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
             check_type(argname="argument id", value=id, expected_type=type_hints["id"])
             check_type(argname="argument props", value=props, expected_type=type_hints["props"])
@@ -683,7 +772,13 @@ class TrailLoggingProps:
         :param name: Property name: The name of the trail to be enabled.
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(TrailLoggingProps.__init__)
+            def stub(
+                *,
+                enable: typing.Union[builtins.bool, ros_cdk_core.IResolvable],
+                name: typing.Union[builtins.str, ros_cdk_core.IResolvable],
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument enable", value=enable, expected_type=type_hints["enable"])
             check_type(argname="argument name", value=name, expected_type=type_hints["name"])
         self._values: typing.Dict[str, typing.Any] = {
@@ -753,7 +848,18 @@ class TrailProps:
         :param sls_write_role_arn: Property slsWriteRoleArn: The unique ARN of the Log Service role.
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(TrailProps.__init__)
+            def stub(
+                *,
+                name: typing.Union[builtins.str, ros_cdk_core.IResolvable],
+                oss_bucket_name: typing.Union[builtins.str, ros_cdk_core.IResolvable],
+                role_name: typing.Union[builtins.str, ros_cdk_core.IResolvable],
+                event_rw: typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]] = None,
+                oss_key_prefix: typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]] = None,
+                sls_project_arn: typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]] = None,
+                sls_write_role_arn: typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]] = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument name", value=name, expected_type=type_hints["name"])
             check_type(argname="argument oss_bucket_name", value=oss_bucket_name, expected_type=type_hints["oss_bucket_name"])
             check_type(argname="argument role_name", value=role_name, expected_type=type_hints["role_name"])
